@@ -4,7 +4,7 @@ import datetime
 from decimal import Decimal
 from trytond.model import ModelView, ModelSQL, fields
 from trytond.wizard import Wizard, StateView, Button, StateAction
-from trytond.backend import TableHandler
+from trytond import backend
 from trytond.pyson import Not, Bool, Eval, Equal, PYSONEncoder, Date
 from trytond.transaction import Transaction
 from trytond.pool import Pool, PoolMeta
@@ -97,13 +97,15 @@ class Location(ModelSQL, ModelView):
         cls._order.insert(0, ('name', 'ASC'))
         cls._error_messages.update({
                 'invalid_type_for_moves': ('Location "%s" with existing moves '
-                    'cannot be changed to a type that does not support moves.'),
+                    'cannot be changed to a type that does not support moves.'
+                    ),
                 'child_of_warehouse': ('Location "%(location)s" must be a '
                     'child of warehouse "%(warehouse)s".'),
                 })
 
     @classmethod
     def __register__(cls, module_name):
+        TableHandler = backend.get('TableHandler')
         super(Location, cls).__register__(module_name)
         cursor = Transaction().cursor
 
@@ -186,12 +188,13 @@ class Location(ModelSQL, ModelView):
                 context['stock_date_end'] = datetime.date.max
 
         location_ids = [l.id for l in locations]
+        product_id = Transaction().context['product']
         with Transaction().set_context(context):
             pbl = Product.products_by_location(location_ids=location_ids,
-                product_ids=[Transaction().context['product']],
-                with_childs=True, skip_zero=False).iteritems()
+                product_ids=[product_id], with_childs=True)
 
-        return dict([(loc, qty) for (loc, prod), qty in pbl])
+        return dict((loc, pbl.get((loc, product_id), 0))
+            for loc in location_ids)
 
     @classmethod
     def get_cost_value(cls, locations, name):
