@@ -260,10 +260,10 @@ class ShipmentIn(Workflow, ModelSQL, ModelView):
         return Transaction().context.get('company')
 
     def on_change_supplier(self):
-        if not self.supplier:
-            return {'contact_address': None}
-        address = self.supplier.address_get()
-        return {'contact_address': address.id}
+        address = None
+        if self.supplier:
+            address = self.supplier.address_get()
+        return {'contact_address': address.id if address else None}
 
     def on_change_with_supplier_location(self, name=None):
         if self.supplier:
@@ -991,10 +991,10 @@ class ShipmentOut(Workflow, ModelSQL, ModelView):
         return Transaction().context.get('company')
 
     def on_change_customer(self):
-        if not self.customer:
-            return {'delivery_address': None}
-        address = self.customer.address_get(type='delivery')
-        return {'delivery_address': address.id}
+        address = None
+        if self.customer:
+            address = self.customer.address_get(type='delivery')
+        return {'delivery_address': address.id if address else None}
 
     def on_change_with_customer_location(self, name=None):
         if self.customer:
@@ -1493,11 +1493,11 @@ class ShipmentOutReturn(Workflow, ModelSQL, ModelView):
         return Transaction().context.get('company')
 
     def on_change_customer(self):
-        if not self.customer:
-            return {'delivery_address': None}
-        address = self.customer.address_get(type='delivery')
+        address = None
+        if self.customer:
+            address = self.customer.address_get(type='delivery')
         return {
-            'delivery_address': address.id,
+            'delivery_address': address.id if address else None,
             }
 
     def on_change_with_customer_location(self, name=None):
@@ -1777,14 +1777,14 @@ class ShipmentInternal(Workflow, ModelSQL, ModelView):
                 Bool(Eval('moves'))),
             },
         domain=[
-            ('type', 'in', ['storage']),
+            ('type', 'in', ['storage', 'lost_found']),
             ], depends=['state', 'moves'])
     to_location = fields.Many2One('stock.location', "To Location",
         required=True, states={
             'readonly': Or(Not(Equal(Eval('state'), 'draft')),
                 Bool(Eval('moves'))),
             }, domain=[
-            ('type', 'in', ['storage']),
+            ('type', 'in', ['storage', 'lost_found']),
             ], depends=['state', 'moves'])
     moves = fields.One2Many('stock.move', 'shipment', 'Moves',
         states={
@@ -1792,7 +1792,8 @@ class ShipmentInternal(Workflow, ModelSQL, ModelView):
                 | ~Eval('from_location') | ~Eval('to_location')),
             },
         domain=[
-            ('from_location', '=', Eval('from_location')),
+            ('from_location', 'child_of', [Eval('from_location', -1)],
+                'parent'),
             ('to_location', '=', Eval('to_location')),
             ('company', '=', Eval('company')),
             ],
